.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`draw`
===================
.. automodule:: skimage.draw

.. currentmodule:: skimage.draw
.. autosummary::

   skimage.draw.bezier_curve
   skimage.draw.circle
   skimage.draw.circle_perimeter
   skimage.draw.circle_perimeter_aa
   skimage.draw.disk
   skimage.draw.ellipse
   skimage.draw.ellipse_perimeter
   skimage.draw.ellipsoid
   skimage.draw.ellipsoid_stats
   skimage.draw.line
   skimage.draw.line_aa
   skimage.draw.line_nd
   skimage.draw.polygon
   skimage.draw.polygon2mask
   skimage.draw.polygon_perimeter
   skimage.draw.random_shapes
   skimage.draw.rectangle
   skimage.draw.rectangle_perimeter
   skimage.draw.set_color



bezier_curve
------------

.. autofunction:: skimage.draw.bezier_curve


.. include:: skimage.draw.bezier_curve.examples

circle
------

.. autofunction:: skimage.draw.circle


.. include:: skimage.draw.circle.examples

circle_perimeter
----------------

.. autofunction:: skimage.draw.circle_perimeter


.. include:: skimage.draw.circle_perimeter.examples

circle_perimeter_aa
-------------------

.. autofunction:: skimage.draw.circle_perimeter_aa


.. include:: skimage.draw.circle_perimeter_aa.examples

disk
----

.. autofunction:: skimage.draw.disk


.. include:: skimage.draw.disk.examples

ellipse
-------

.. autofunction:: skimage.draw.ellipse


.. include:: skimage.draw.ellipse.examples

ellipse_perimeter
-----------------

.. autofunction:: skimage.draw.ellipse_perimeter


.. include:: skimage.draw.ellipse_perimeter.examples

ellipsoid
---------

.. autofunction:: skimage.draw.ellipsoid


.. include:: skimage.draw.ellipsoid.examples

ellipsoid_stats
---------------

.. autofunction:: skimage.draw.ellipsoid_stats


.. include:: skimage.draw.ellipsoid_stats.examples

line
----

.. autofunction:: skimage.draw.line


.. include:: skimage.draw.line.examples

line_aa
-------

.. autofunction:: skimage.draw.line_aa


.. include:: skimage.draw.line_aa.examples

line_nd
-------

.. autofunction:: skimage.draw.line_nd


.. include:: skimage.draw.line_nd.examples

polygon
-------

.. autofunction:: skimage.draw.polygon


.. include:: skimage.draw.polygon.examples

polygon2mask
------------

.. autofunction:: skimage.draw.polygon2mask


.. include:: skimage.draw.polygon2mask.examples

polygon_perimeter
-----------------

.. autofunction:: skimage.draw.polygon_perimeter


.. include:: skimage.draw.polygon_perimeter.examples

random_shapes
-------------

.. autofunction:: skimage.draw.random_shapes


.. include:: skimage.draw.random_shapes.examples

rectangle
---------

.. autofunction:: skimage.draw.rectangle


.. include:: skimage.draw.rectangle.examples

rectangle_perimeter
-------------------

.. autofunction:: skimage.draw.rectangle_perimeter


.. include:: skimage.draw.rectangle_perimeter.examples

set_color
---------

.. autofunction:: skimage.draw.set_color


.. include:: skimage.draw.set_color.examples

